@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-use strict;
+use v5.26;
 use warnings;
 
 use Device::Chip::PCF8574;
@@ -8,25 +8,32 @@ use Device::Chip::Adapter;
 
 use Time::HiRes qw( sleep );
 
+use Future::AsyncAwait;
+
 use Getopt::Long;
 
 GetOptions(
-   'adapter|A=s' => \( my $ADAPTER = "BusPirate" ),
-   'mount|M=s'   => \( my $MOUNTPARAMS ),
+   'adapter|A=s' => \my $ADAPTER,
+   'mount|M=s'   => \my $MOUNTPARAMS,
+
+   'invert|i' => \my $INVERT,
 ) or exit 1;
 
 my $chip = Device::Chip::PCF8574->new;
-$chip->mount_from_paramstr(
+await $chip->mount_from_paramstr(
    Device::Chip::Adapter->new_from_description( $ADAPTER ), $MOUNTPARAMS,
-)->get;
+);
 
-$chip->protocol->power(1)->get;
+await $chip->protocol->power(1);
 
 END { $chip->protocol->power(0)->get; }
 $SIG{INT} = $SIG{TERM} = sub { exit 1 };
 
 while(1) {
-   printf "Read %02x\n", $chip->read()->get;
+   my $bits = await $chip->read;
+   $bits ^= 0xff if $INVERT;
+
+   printf "Read %02x\n", $bits;
 
    sleep 0.1;
 }
